@@ -64,7 +64,7 @@ Variable::Variable(TreeModel* model, TreeItem* parent,
                    const QString& expression,
                    const QString& display)
   : TreeItem(model, parent),
-    inScope_(true), topLevel_(true)
+    inScope_(true), topLevel_(true), changed_(false), m_format(Natural)
 {
     expression_ = expression;
     // FIXME: should not duplicate the data, instead overload 'data'
@@ -91,6 +91,11 @@ void Variable::setValue(const QString& v)
     reportChange();
 }
 
+QString Variable::value() const
+{
+    return itemData[1].toString();
+}
+
 void Variable::setTopLevel(bool v)
 {
     topLevel_ = v;
@@ -117,16 +122,70 @@ void Variable::die()
     deleteLater();
 }
 
+
+void Variable::setChanged(bool c)
+{
+    changed_=c;
+    reportChange();
+}
+
+void Variable::resetChanged()
+{
+    setChanged(false);
+    for (int i=0; i<childCount(); ++i) {
+        TreeItem* childItem = child(i);
+        if (dynamic_cast<Variable*>(childItem)) {
+            static_cast<Variable*>(childItem)->resetChanged();
+        }
+    }
+}
+
+Variable::format_t Variable::str2format(const QString& str)
+{
+    if(str=="Binary" || str=="binary")          return Binary;
+    if(str=="Octal" || str=="octal")            return Octal;
+    if(str=="Decimal" || str=="decimal")        return Decimal;
+    if(str=="Hexadecimal" || str=="hexadecimal")return Hexadecimal;
+
+    return Natural; // maybe most reasonable default
+}
+
+QString Variable::format2str(format_t format)
+{
+    switch(format) {
+        case Natural:       return "natural";
+        case Binary:        return "binary";
+        case Octal:         return "octal";
+        case Decimal:       return "decimal";
+        case Hexadecimal:   return "hexadecimal";
+        default:            return "";
+    }
+}
+
+
+void Variable::setFormat(Variable::format_t format)
+{
+    if (m_format != format) {
+        m_format = format;
+        formatChanged();
+    }
+}
+
+void Variable::formatChanged()
+{
+}
+
 QVariant Variable::data(int column, int role) const
 {
-    if (column == 1 && role == Qt::ForegroundRole
-        && !inScope_)
+    if (column == 1 && role == Qt::ForegroundRole)
     {
         // FIXME: returning hardcoded gray is bad,
         // but we don't have access to any widget, or pallette
         // thereof, at this point.
-        return QColor(128, 128, 128);
+        if(!inScope_) return QColor(128, 128, 128);
+        if(changed_) return QColor(255, 0, 0);
     }
+   
     return TreeItem::data(column, role);
 }
 
@@ -169,6 +228,16 @@ void Watches::removeFinishResult()
     }
 }
 
+void Watches::resetChanged()
+{
+    for (int i=0; i<childCount(); ++i) {
+        TreeItem* childItem = child(i);
+        if (dynamic_cast<Variable*>(childItem)) {
+            static_cast<Variable*>(childItem)->resetChanged();
+        }
+    }
+}
+
 QVariant Watches::data(int column, int role) const
 {
 #if 0
@@ -204,7 +273,8 @@ QList<Variable*> Locals::updateLocals(QStringList locals)
     for (int i = 0; i < childItems.size(); i++)
     {
         Q_ASSERT(dynamic_cast<KDevelop::Variable*>(child(i)));
-        existing << static_cast<KDevelop::Variable*>(child(i))->expression();
+        Variable* var= static_cast<KDevelop::Variable*>(child(i));
+        existing << var->expression();
     }
 
     foreach (const QString& var, locals) {
@@ -248,6 +318,16 @@ QList<Variable*> Locals::updateLocals(QStringList locals)
     return ret;
 }
 
+void Locals::resetChanged()
+{
+    for (int i=0; i<childCount(); ++i) {
+        TreeItem* childItem = child(i);
+        if (dynamic_cast<Variable*>(childItem)) {
+            static_cast<Variable*>(childItem)->resetChanged();
+        }
+    }
+}
+
 VariablesRoot::VariablesRoot(TreeModel* model)
 : TreeItem(model)
 {
@@ -270,6 +350,14 @@ QHash<QString, Locals*> VariablesRoot::allLocals() const
     return locals_;
 }
 
+void VariablesRoot::resetChanged()
+{
+    watches_->resetChanged();
+    foreach (Locals *l, locals_) {
+        l->resetChanged();
+    }
+}
+
 VariableCollection::VariableCollection(IDebugController* controller)
 : TreeModel(QVector<QString>() << "Name" << "Value", controller), m_widgetVisible(false)
 {
