@@ -19,6 +19,8 @@
 #ifndef IPATCHDOCUMENT_H
 #define IPATCHDOCUMENT_H
 
+#include "interfacesexport.h"
+
 class KUrl;
 class QString;
 
@@ -28,8 +30,8 @@ namespace KDevelop
 class KDEVPLATFORMINTERFACES_EXPORT IPatchDocument
 {
     public:
-        virtual ~IPatchDocument() {}
-        virtual void setDiff(const QString& tocompare, const KUrl& file)=0;
+        virtual ~IPatchDocument();
+        virtual void setDiff(const QString& tocompare, const KUrl& file) = 0;
 };
 
 }
