@@ -28,7 +28,6 @@
 #include <QtCore/QList>
 #include <QtCore/QPointer>
 #include <QtCore/QPair>
-#include <QtDesigner/QExtensionManager>
 #include "interfacesexport.h"
 
 class KIconLoader;
@@ -43,7 +42,7 @@ namespace Sublime {
  * to make sure old source (or binary) incompatible plugins are not loaded.
  * Increase this if it is necessary that old plugins stop working.
  */
-#define KDEVELOP_PLUGIN_VERSION 9
+#define KDEVELOP_PLUGIN_VERSION 10
 
 /**
  * This macro adds an extension interface to register with the extension manager
@@ -51,7 +50,7 @@ namespace Sublime {
  */
 
 #define KDEV_USE_EXTENSION_INTERFACE( Extension ) \
-    addExtension( Q_TYPEID( Extension ) );
+    addExtension( qobject_interface_iid<Extension*>() );
 
 namespace KDevelop
 {
@@ -172,16 +171,16 @@ public:
      */
     Q_SCRIPTABLE ICore *core() const;
 
-    Q_SCRIPTABLE void registerExtensions();
-    Q_SCRIPTABLE void unregisterExtensions();
-
     Q_SCRIPTABLE QStringList extensions() const;
 
     template<class Extension> Extension* extension()
     {
-        return qt_extension<Extension*>( extensionManager(), this );
+        if( extensions().contains( qobject_interface_iid<Extension*>() ) ) {
+            return qobject_cast<Extension*>( this );
+        }
+        return 0;
     }
-
+    
     /**
      * ask the plugin for a ContextActionContainer, which contains actions
      * that will be merged into the context menu.
@@ -234,7 +233,6 @@ private:
 
     friend class IPluginPrivate;
     class IPluginPrivate* const d;
-    QExtensionManager* extensionManager();
 };
 
 }
