@@ -196,7 +196,10 @@ public Q_SLOTS:
     
     ///Returns true if the given url is queued for parsing
     bool isQueued(KUrl url) const;
-    
+
+    ///Returns the number of currently active or queued jobs
+    int queuedCount() const;
+
 protected:
     void loadSettings(bool projectIsLoaded);
     void saveSettings(bool projectIsLoaded);
@@ -205,6 +208,7 @@ protected Q_SLOTS:
     void parseComplete(ThreadWeaver::Job *job);
     void parseProgress(KDevelop::ParseJob*, float value, QString text);
     void startTimer();
+    void aboutToQuit();
 
 protected:
     // Receive changed notifications
