@@ -74,8 +74,14 @@ DEFINE_LIST_MEMBER_HASH(DUContextData, m_uses, Use)
 REGISTER_DUCHAIN_ITEM(DUContext);
 
 //We leak here, to prevent a possible crash during destruction, as the destructor of Identifier is not safe to be called after the duchain has been destroyed
-const Identifier& globalImportIdentifier(*new Identifier("{...import...}"));
-const Identifier& globalAliasIdentifier(*new Identifier("{...alias...}"));
+Identifier& globalImportIdentifier() {
+  static Identifier globalImportIdentifierObject(*new Identifier("{...import...}"));
+  return globalImportIdentifierObject;
+}
+Identifier& globalAliasIdentifier() {
+  static Identifier globalAliasIdentifierObject(*new Identifier("{...alias...}"));
+  return globalAliasIdentifierObject;
+}
 
 void DUContext::rebuildDynamicData(DUContext* parent, uint ownIndex) {
 
@@ -1358,7 +1364,7 @@ QVector<DUContext::Import> DUContext::importedParentContexts() const
 void DUContext::applyAliases(const SearchItem::PtrList& baseIdentifiers, SearchItem::PtrList& identifiers, const SimpleCursor& position, bool canBeNamespace, bool onlyImports) const {
 
   DeclarationList imports;
-  findLocalDeclarationsInternal(globalImportIdentifier, position, AbstractType::Ptr(), imports, topContext(), DUContext::NoFiltering);
+  findLocalDeclarationsInternal(globalImportIdentifier(), position, AbstractType::Ptr(), imports, topContext(), DUContext::NoFiltering);
   
   if(imports.isEmpty() && onlyImports) {
     identifiers = baseIdentifiers;
@@ -1376,9 +1382,13 @@ void DUContext::applyAliases(const SearchItem::PtrList& baseIdentifiers, SearchI
         FOREACH_ARRAY( Declaration* importDecl, imports )
         {
           //Search for the identifier with the import-identifier prepended
-          Q_ASSERT(dynamic_cast<NamespaceAliasDeclaration*>(importDecl));
-          NamespaceAliasDeclaration* alias = static_cast<NamespaceAliasDeclaration*>(importDecl);
-          identifiers.append( SearchItem::Ptr( new SearchItem( alias->importIdentifier(), identifier ) ) ) ;
+          if(dynamic_cast<NamespaceAliasDeclaration*>(importDecl))
+          {
+            NamespaceAliasDeclaration* alias = static_cast<NamespaceAliasDeclaration*>(importDecl);
+            identifiers.append( SearchItem::Ptr( new SearchItem( alias->importIdentifier(), identifier ) ) ) ;
+          }else{
+            kDebug() << "Declaration with namespace alias identifier has the wrong type" << importDecl->url().str() << importDecl->range().textRange();
+          }
         }
       }
 
