@@ -88,6 +88,9 @@ void ArrayType::setElementType(AbstractType::Ptr type)
 
 QString ArrayType::toString() const
 {
+  if (d_func()->m_dimension == 0) {
+    return QString("%1[]").arg(elementType() ? elementType()->toString() : QString("<notype>"));
+  }
   return QString("%1[%2]").arg(elementType() ? elementType()->toString() : QString("<notype>")).arg(d_func()->m_dimension);
 }
 
