@@ -1,7 +1,5 @@
 /* This file is part of KDevelop
-    Copyright 2006 Roberto Raggi <roberto@kdevelop.org>
-    Copyright 2006 Hamish Rodda <rodda@kde.org>
-    Copyright 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
+   Copyright 2007-2009 David Nolden <david.nolden.kdevelop@art-master.de>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,16 +19,44 @@
 #include "indexedtype.h"
 
 #include "../repositories/typerepository.h"
+#include "../referencecounting.h"
 
 namespace KDevelop
 {
 
-AbstractType::Ptr IndexedType::type() const {
+IndexedType::IndexedType(uint index) : m_index(index) {
+  if(m_index && shouldDoDUChainReferenceCounting(this))
+    TypeRepository::increaseReferenceCount(m_index, this);
+}
+
+IndexedType::IndexedType(const IndexedType& rhs) : m_index(rhs.m_index) {
+  if(m_index && shouldDoDUChainReferenceCounting(this))
+    TypeRepository::increaseReferenceCount(m_index, this);
+}
+
+IndexedType::~IndexedType() {
+  if(m_index && shouldDoDUChainReferenceCounting(this))
+    TypeRepository::decreaseReferenceCount(m_index, this);
+}
+
+IndexedType& IndexedType::operator=(const IndexedType& rhs) {
+  
+  if(m_index && shouldDoDUChainReferenceCounting(this))
+    TypeRepository::decreaseReferenceCount(m_index, this);
+
+  m_index = rhs.m_index;
+  
+  if(m_index && shouldDoDUChainReferenceCounting(this))
+    TypeRepository::increaseReferenceCount(m_index, this);
+  
+  return *this;
+}
+
+AbstractType::Ptr IndexedType::abstractType() const {
   if(!m_index)
     return AbstractType::Ptr();
   return TypeRepository::typeForIndex(m_index);
 }
-
 }
 
 // kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
