@@ -35,6 +35,9 @@
 #include <vcs/dvcs/dvcsjob.h>
 #include "../gitplugin.h"
 
+#define VERIFYJOB(j) \
+QVERIFY(j); QVERIFY(j->exec()); QVERIFY((j)->status() == KDevelop::VcsJob::JobSucceeded)
+
 const QString tempDir = QDir::tempPath();
 const QString gitTest_BaseDir(tempDir + "/kdevGit_testdir/");
 const QString gitTest_BaseDir2(tempDir + "/kdevGit_testdir2/");
@@ -78,12 +81,7 @@ void GitInitTest::repoInit()
     kDebug() << "Trying to init repo";
     // make job that creates the local repository
     VcsJob* j = m_plugin->init(KUrl(gitTest_BaseDir));
-    QVERIFY(j);
-
-
-    // try to start the job
-    QVERIFY(j->exec());
-    QVERIFY(j->status() == KDevelop::VcsJob::JobSucceeded);
+    VERIFYJOB(j);
 
     //check if the CVSROOT directory in the new local repository exists now
     QVERIFY(QFileInfo(gitRepo).exists());
@@ -113,8 +111,6 @@ void GitInitTest::addFiles()
         input << "HELLO WORLD";
     }
 
-    f.flush();
-
     f.close();
     f.setFileName(gitTest_BaseDir + gitTest_FileName2);
 
@@ -123,21 +119,15 @@ void GitInitTest::addFiles()
         input << "No, bar()!";
     }
 
-    f.flush();
-
     f.close();
 
     //test git-status exitCode (see DVcsJob::setExitCode).
     VcsJob* j = m_plugin->status(KUrl::List(gitTest_BaseDir));
-    QVERIFY(j);
-    QVERIFY(j->exec());
-    QVERIFY(j->status() == KDevelop::VcsJob::JobSucceeded);
+    VERIFYJOB(j);
 
     // /tmp/kdevGit_testdir/ and testfile
     j = m_plugin->add(KUrl::List(gitTest_BaseDir + gitTest_FileName));
-    QVERIFY(j);
-    QVERIFY(j->exec());
-    QVERIFY(j->status() == KDevelop::VcsJob::JobSucceeded);
+    VERIFYJOB(j);
 
     f.setFileName(gitSrcDir + gitTest_FileName3);
 
@@ -146,28 +136,20 @@ void GitInitTest::addFiles()
         input << "No, foo()! It's bar()!";
     }
 
-    f.flush();
-
     f.close();
 
     //test git-status exitCode again
     j = m_plugin->status(KUrl::List(gitTest_BaseDir));
-    QVERIFY(j);
-    QVERIFY(j->exec());
-    QVERIFY(j->status() == KDevelop::VcsJob::JobSucceeded);
+    VERIFYJOB(j);
 
     //repository path without trailing slash and a file in a parent directory
     // /tmp/repo  and /tmp/repo/src/bar
     j = m_plugin->add(KUrl::List(QStringList(gitSrcDir + gitTest_FileName3)));
-    QVERIFY(j);
-    QVERIFY(j->exec());
-    QVERIFY(j->status() == KDevelop::VcsJob::JobSucceeded);
+    VERIFYJOB(j);
 
     //let's use absolute path, because it's used in ContextMenus
     j = m_plugin->add(KUrl::List(QStringList(gitTest_BaseDir + gitTest_FileName2)));
-    QVERIFY(j);
-    QVERIFY(j->exec());
-    QVERIFY(j->status() == KDevelop::VcsJob::JobSucceeded);
+    VERIFYJOB(j);
 
     //Now let's create several files and try "git add file1 file2 file3"
     f.setFileName(gitTest_BaseDir + "file1");
@@ -177,8 +159,6 @@ void GitInitTest::addFiles()
         input << "file1";
     }
 
-    f.flush();
-
     f.close();
     f.setFileName(gitTest_BaseDir + "file2");
 
@@ -186,41 +166,25 @@ void GitInitTest::addFiles()
         QTextStream input(&f);
         input << "file2";
     }
-
-    f.flush();
-
     f.close();
-    QStringList multipleFiles;
+    
+    KUrl::List multipleFiles;
     multipleFiles << (gitTest_BaseDir + "file1");
     multipleFiles << (gitTest_BaseDir + "file2");
-    j = m_plugin->add(KUrl::List(multipleFiles));
-    QVERIFY(j);
-    QVERIFY(j->exec());
-    QVERIFY(j->status() == KDevelop::VcsJob::JobSucceeded);
+    j = m_plugin->add(multipleFiles);
+    VERIFYJOB(j);
 }
 
 void GitInitTest::commitFiles()
 {
-    kDebug() << "\nListing variables with KProcess\n";
-    DVcsJob* j_var = m_plugin->var(gitTest_BaseDir);
-    QVERIFY(j_var->exec());
-    QVERIFY(j_var->status() == KDevelop::VcsJob::JobSucceeded);
-
     kDebug() << "Committing...";
     //we start it after addFiles, so we just have to commit
-    ///TODO: if "" is ok?
     VcsJob* j = m_plugin->commit(QString("Test commit"), KUrl::List(gitTest_BaseDir));
-    QVERIFY(j);
-
-    // try to start the job
-    QVERIFY(j->exec());
-    QVERIFY(j->status() == KDevelop::VcsJob::JobSucceeded);
+    VERIFYJOB(j);
 
     //test git-status exitCode one more time.
     j = m_plugin->status(KUrl::List(gitTest_BaseDir));
-    QVERIFY(j);
-    QVERIFY(j->exec());
-    QVERIFY(j->status() == KDevelop::VcsJob::JobSucceeded);
+    VERIFYJOB(j);
 
     //since we commited the file to the "pure" repository, .git/refs/heads/master should exist
     //TODO: maybe other method should be used
@@ -228,15 +192,10 @@ void GitInitTest::commitFiles()
     QVERIFY(QFileInfo(headRefName).exists());
 
     //Test the results of the "git add"
-    DVcsJob* jobLs = new DVcsJob(0);
-    jobLs->clear();
-    jobLs->setDirectory(gitTest_BaseDir);
+    DVcsJob* jobLs = new DVcsJob(gitTest_BaseDir, m_plugin);
     *jobLs << "git" << "ls-tree" << "--name-only" << "-r" << "HEAD";
 
-    if (jobLs) {
-        QVERIFY(jobLs->exec());
-        QVERIFY(jobLs->status() == KDevelop::VcsJob::JobSucceeded);
-
+    if (jobLs->exec() && jobLs->status() == KDevelop::VcsJob::JobSucceeded) {
         QStringList files = jobLs->output().split("\n");
         QVERIFY(files.contains(gitTest_FileName));
         QVERIFY(files.contains(gitTest_FileName2));
@@ -251,12 +210,9 @@ void GitInitTest::commitFiles()
         QTextStream output(&headRef);
         output >> firstCommit;
     }
-
-    headRef.flush();
-
     headRef.close();
 
-    QVERIFY(firstCommit != "");
+    QVERIFY(!firstCommit.isEmpty());
 
     kDebug() << "Committing one more time";
     //let's try to change the file and test "git commit -a"
@@ -267,22 +223,14 @@ void GitInitTest::commitFiles()
         input << "Just another HELLO WORLD";
     }
 
-    f.flush();
+    f.close();
 
     //add changes
     j = m_plugin->add(KUrl::List(QStringList(gitTest_BaseDir + gitTest_FileName)));
-    QVERIFY(j);
-
-    // try to start the job
-    QVERIFY(j->exec());
-    QVERIFY(j->status() == KDevelop::VcsJob::JobSucceeded);
+    VERIFYJOB(j);
 
     j = m_plugin->commit(QString("KDevelop's Test commit2"), KUrl::List(gitTest_BaseDir));
-    QVERIFY(j);
-
-    // try to start the job
-    QVERIFY(j->exec());
-    QVERIFY(j->status() == KDevelop::VcsJob::JobSucceeded);
+    VERIFYJOB(j);
 
     QString secondCommit;
 
@@ -290,12 +238,9 @@ void GitInitTest::commitFiles()
         QTextStream output(&headRef);
         output >> secondCommit;
     }
-
-    headRef.flush();
-
     headRef.close();
 
-    QVERIFY(secondCommit != "");
+    QVERIFY(!secondCommit.isEmpty());
     QVERIFY(firstCommit != secondCommit);
 
 }
@@ -332,30 +277,22 @@ void GitInitTest::testCommit()
 void GitInitTest::testBranching()
 {
     DVcsJob* j = m_plugin->branch(gitTest_BaseDir);
-    QVERIFY(j);
-    QVERIFY(j->exec());
-    QVERIFY(j->status() == KDevelop::VcsJob::JobSucceeded);
+    VERIFYJOB(j);
 
     QString curBranch = m_plugin->curBranch(gitTest_BaseDir);
     QCOMPARE(curBranch, QString("master"));
 
     QString newBranch("new");
     j = m_plugin->branch(gitTest_BaseDir, QString("master"), newBranch);
-    QVERIFY(j);
-    QVERIFY(j->exec());
-    QVERIFY(j->status() == KDevelop::VcsJob::JobSucceeded);
+    VERIFYJOB(j);
     QVERIFY(m_plugin->branches(gitTest_BaseDir).contains(newBranch));
 
     j = m_plugin->switchBranch(gitTest_BaseDir, newBranch);
-    QVERIFY(j);
-    QVERIFY(j->exec());
-    QVERIFY(j->status() == KDevelop::VcsJob::JobSucceeded);
+    VERIFYJOB(j);
     QCOMPARE(m_plugin->curBranch(gitTest_BaseDir), newBranch);
 
     j = m_plugin->branch(gitTest_BaseDir, QString("master"), QString(), QStringList("-D"));
-    QVERIFY(j);
-    QVERIFY(j->exec());
-    QVERIFY(j->status() == KDevelop::VcsJob::JobSucceeded);
+    VERIFYJOB(j);
     QVERIFY(!m_plugin->branches(gitTest_BaseDir).contains(QString("master")));
 }
 
