@@ -21,6 +21,7 @@
 
 #include <QtCore/QList>
 #include <QtGui/QInputDialog>
+#include <QtGui/QApplication>
 
 #include <kaction.h>
 #include <kactioncollection.h>
@@ -70,7 +71,7 @@ class KDevProjectManagerViewFactory: public KDevelop::IToolViewFactory
         {
             return "org.kdevelop.ProjectsView";
         }
-        
+
     private:
         ProjectManagerViewPlugin *mplugin;
 };
@@ -123,6 +124,10 @@ ProjectManagerViewPlugin::ProjectManagerViewPlugin( QObject *parent, const QVari
     d->m_prune->setEnabled( false );
     connect( d->m_prune, SIGNAL(triggered()), this, SLOT(pruneProjectItems()) );
     actionCollection()->addAction( "project_prune", d->m_prune );
+    // only add the action so that its known in the actionCollection
+    // and so that it's shortcut etc. pp. is restored
+    // apparently that is not possible to be done in the view itself *sigh*
+    actionCollection()->addAction( "locate_document" );
     setXMLFile( "kdevprojectmanagerview.rc" );
     d->factory = new KDevProjectManagerViewFactory( this );
     core()->uiController()->addToolView( i18n("Projects"), d->factory );
@@ -144,7 +149,7 @@ void ProjectManagerViewPlugin::updateFromBuildSetChange()
 void ProjectManagerViewPlugin::updateActionState( KDevelop::Context* ctx )
 {
     bool isEmpty = ICore::self()->projectController()->buildSetModel()->items().isEmpty();
-    if( isEmpty ) 
+    if( isEmpty )
     {
         isEmpty = !ctx || ctx->type() != Context::ProjectItemContext || dynamic_cast<ProjectItemContext*>( ctx )->items().isEmpty();
     }
@@ -226,7 +231,7 @@ ContextMenuExtension ProjectManagerViewPlugin::contextMenuExtension( KDevelop::C
         }
 
         KDevelop::ProjectFolderItem *prjitem = item->folder();
-        if ( !closeProjectsAdded && prjitem && prjitem->isProjectRoot() )
+        if ( !closeProjectsAdded && prjitem && !prjitem->parent() )
         {
             KAction* close = new KAction( i18np( "Close Project", "Close Projects", items.count() ), this );
             close->setIcon(KIcon("project-development-close"));
@@ -244,7 +249,7 @@ ContextMenuExtension ProjectManagerViewPlugin::contextMenuExtension( KDevelop::C
             connect( action, SIGNAL(triggered()), this, SLOT(reloadFromContextMenu()) );
             menuExt.addAction( ContextMenuExtension::FileGroup, action );
         }
-        
+
         if ( !removeAdded && ((item->folder() && item->parent()) || item->file()) )
         {
             removeAdded = true;
@@ -253,7 +258,7 @@ ContextMenuExtension ProjectManagerViewPlugin::contextMenuExtension( KDevelop::C
             connect( action, SIGNAL(triggered()), this, SLOT(removeFromContextMenu()) );
             menuExt.addAction( ContextMenuExtension::FileGroup, action );
         }
-        
+
         if( !renameAdded && (item->file() || item->folder()) && item->parent() )
         {
             renameAdded = true;
@@ -262,7 +267,7 @@ ContextMenuExtension ProjectManagerViewPlugin::contextMenuExtension( KDevelop::C
             connect( action, SIGNAL(triggered()), this, SLOT(renameItemFromContextMenu()) );
             menuExt.addAction( ContextMenuExtension::FileGroup, action );
         }
-        
+
         //TODO: Port to launch framework
 //         if(!hasTargets && item->executable())
 //         {
@@ -273,7 +278,7 @@ ContextMenuExtension ProjectManagerViewPlugin::contextMenuExtension( KDevelop::C
 //         }
 
     }
-    
+
     return menuExt;
 }
 
@@ -459,10 +464,18 @@ void ProjectManagerViewPlugin::removeFromContextMenu()
     foreach( KDevelop::ProjectBaseItem* item, d->ctxProjectItemList )
     {
         if ( item->folder() || item->file() ) {
-            if ( item->folder() ) {
-                item->project()->projectFileManager()->removeFolder(item->folder());
-            } else {
-                item->project()->projectFileManager()->removeFile(item->file());
+
+            QWidget* window(QApplication::activeWindow());
+            int q=KMessageBox::questionYesNo(window,
+                item->folder() ? i18n("Do you really want to remove the directory <i>%1</i>?", item->folder()->url().pathOrUrl())
+                        : i18n("Do you really to remove the file <i>%1</i>?", item->file()->url().pathOrUrl()));
+            if(q==KMessageBox::Yes)
+            {
+                if ( item->folder() ) {
+                    item->project()->projectFileManager()->removeFolder(item->folder());
+                } else {
+                    item->project()->projectFileManager()->removeFile(item->file());
+                }
             }
         }
     }
@@ -481,7 +494,7 @@ void ProjectManagerViewPlugin::renameItemFromContextMenu()
             continue;
         }
 
-        const QString src = item->data(Qt::EditRole).toString();
+        const QString src = item->text();
 
         //Change QInputDialog->KFileSaveDialog?
         QString name = QInputDialog::getText(
@@ -491,7 +504,22 @@ void ProjectManagerViewPlugin::renameItemFromContextMenu()
         );
 
         if (!name.isEmpty() && name != src) {
-            item->setData(name, Qt::EditRole);
+            ProjectBaseItem::RenameStatus status = item->rename( name );
+            
+            QWidget* window(QApplication::activeWindow());
+            switch(status) {
+                case ProjectBaseItem::RenameOk:
+                    break;
+                case ProjectBaseItem::ExistingItemSameName:
+                    KMessageBox::error(window, i18n("There already is a file called like '%1'", name));
+                    break;
+                case ProjectBaseItem::ProjectManagerRenameFailed:
+                    KMessageBox::error(window, i18n("Could not rename '%1'", name));
+                    break;
+                case ProjectBaseItem::InvalidNewName:
+                    KMessageBox::error(window, i18n("'%1' is not a valid file name", name));
+                    break;
+            }
         }
     }
 }
@@ -500,10 +528,10 @@ ProjectFileItem* createFile(const ProjectFolderItem* item)
 {
     QWidget* window = ICore::self()->uiController()->activeMainWindow()->window();
     QString name = QInputDialog::getText(window, i18n("Create File in %1", item->url().prettyUrl()), i18n("File Name"));
-    
+
     if(name.isEmpty())
         return 0;
-    
+
     KUrl url=item->url();
     url.addPath( name );
 
