@@ -25,11 +25,14 @@
 
 #include "snippetstore.h"
 
+#include "snippetfeatures.h"
+
 EditRepository::EditRepository(SnippetRepository* repository, QWidget* parent)
     : KDialog(parent), Ui::EditRepositoryBase(), m_repo(repository)
 {
     setButtons(/*Reset | */Apply | Cancel | Ok);
     setupUi(mainWidget());
+    mainWidget()->layout()->setMargin(0);
 
     connect(this, SIGNAL(okClicked()), this, SLOT(save()));
     connect(this, SIGNAL(applyClicked()), this, SLOT(save()));
@@ -43,7 +46,7 @@ EditRepository::EditRepository(SnippetRepository* repository, QWidget* parent)
     repoFileTypesList->sortItems();
     repoFileTypesList->setSelectionMode(QAbstractItemView::ExtendedSelection);
     connect(repoFileTypesList->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            this, SLOT(updateFileTypesEdit()));
+            this, SLOT(updateFileTypes()));
 
     delete document;
 
@@ -52,10 +55,19 @@ EditRepository::EditRepository(SnippetRepository* repository, QWidget* parent)
     repoLicenseEdit->setCurrentIndex(1); // preselect BSD
     repoLicenseEdit->setEditable(true);
 
+#ifndef SNIPPETS_HAVE_TPLIFACE2
+    tabWidget->setTabEnabled(1, false);
+    tabWidget->setTabToolTip(1, i18n("You need at least KDE 4.5 for scripting support in snippets."));
+#endif
+
     // if we edit a repo, add all existing data
     if ( m_repo ) {
         repoNameEdit->setText(m_repo->text());
         repoAuthorsEdit->setText(m_repo->authors());
+        repoNamespaceEdit->setText(m_repo->completionNamespace());
+        ///TODO: Use KTextEditor here
+        ///      improve documentation, link to correct part in Kate's documentation.
+        repoScriptEdit->setPlainText(m_repo->script());
         if ( !m_repo->license().isEmpty() ) {
             int index = repoLicenseEdit->findText(m_repo->license());
             if ( index == -1 ) {
@@ -79,7 +91,7 @@ EditRepository::EditRepository(SnippetRepository* repository, QWidget* parent)
     }
 
     validate();
-    updateFileTypesEdit();
+    updateFileTypes();
     repoNameEdit->setFocus();
 }
 
@@ -104,20 +116,30 @@ void EditRepository::save()
     m_repo->setText(repoNameEdit->text());
     m_repo->setAuthors(repoAuthorsEdit->text());
     m_repo->setLicense(repoLicenseEdit->currentText());
+    m_repo->setCompletionNamespace(repoNamespaceEdit->text());
+    m_repo->setScript(repoScriptEdit->toPlainText());
 
-    m_repo->setFileTypes(repoFileTypesEdit->text().split(";", QString::SkipEmptyParts));
+    QStringList types;
+    foreach( QListWidgetItem* item, repoFileTypesList->selectedItems() ) {
+        types << item->text();
+    }
+    m_repo->setFileTypes(types);
     m_repo->save();
 
     setWindowTitle(i18n("Edit Snippet Repository %1", m_repo->text()));
 }
 
-void EditRepository::updateFileTypesEdit()
+void EditRepository::updateFileTypes()
 {
     QStringList types;
     foreach( QListWidgetItem* item, repoFileTypesList->selectedItems() ) {
         types << item->text();
     }
-    repoFileTypesEdit->setText(types.join(";"));
+    if ( types.isEmpty() ) {
+        repoFileTypesListLabel->setText(i18n("<i>leave empty for general purpose snippets</i>"));
+    } else {
+        repoFileTypesListLabel->setText(types.join(", "));
+    }
 }
 
 #include "editrepository.moc"
