@@ -18,6 +18,10 @@ SvnImportMetadataWidget::SvnImportMetadataWidget( QWidget *parent )
 {
     m_ui->setupUi( this );
     m_ui->srcEdit->setUrl( KUrl() );
+    connect( m_ui->srcEdit, SIGNAL( textChanged(QString)), SIGNAL(changed()) );
+    connect( m_ui->srcEdit, SIGNAL(urlSelected(KUrl)), SIGNAL(changed()) );
+    connect( m_ui->dest, SIGNAL(textChanged()), this, SIGNAL(changed()) );
+    connect( m_ui->message, SIGNAL(textChanged()), this, SIGNAL(changed()) );
 }
 
 SvnImportMetadataWidget::~SvnImportMetadataWidget()
@@ -38,11 +42,11 @@ KUrl SvnImportMetadataWidget::source() const
 KDevelop::VcsLocation SvnImportMetadataWidget::destination() const
 {
     KDevelop::VcsLocation destloc;
-    KUrl url = m_ui->dest->url();
+    QString url = m_ui->dest->text();
     if( useSourceDirForDestination ) {
-        url.addPath( m_ui->srcEdit->url().fileName() );
+        url += "/" + m_ui->srcEdit->url().fileName();
     }
-    destloc.setRepositoryServer(url.url());
+    destloc.setRepositoryServer(url);
     return destloc;
 }
 
@@ -62,4 +66,10 @@ QString SvnImportMetadataWidget::message() const
     return m_ui->message->toPlainText();
 }
 
+bool SvnImportMetadataWidget::hasValidData() const
+{
+    return !m_ui->message->toPlainText().isEmpty() && !m_ui->srcEdit->text().isEmpty();
+}
+
+
 #include "svnimportmetadatawidget.moc"
