@@ -37,7 +37,6 @@
 
 #include "shellextension.h"
 
-
 #include "mainwindow.h"
 #include "sessioncontroller.h"
 #include "uicontroller.h"
@@ -47,6 +46,7 @@
 #include "languagecontroller.h"
 #include "documentcontroller.h"
 #include "runcontroller.h"
+#include "session.h"
 #include "documentationcontroller.h"
 #include "sourceformattercontroller.h"
 #include "progressmanager.h"
@@ -91,7 +91,7 @@ CorePrivate::CorePrivate(Core *core):
 {
 }
 
-bool CorePrivate::initialize(Core::Setup mode)
+bool CorePrivate::initialize(Core::Setup mode, const QString& session )
 {
     m_mode=mode;
     if( !sessionController )
@@ -164,13 +164,24 @@ bool CorePrivate::initialize(Core::Setup mode)
     }
 
     kDebug() << "initializing ui controller";
-    sessionController->initialize();
-    
-    if(!(mode & Core::NoUi) && !sessionController->lockSession())
+    sessionController->initialize( session );
+
+    if(!sessionController->lockSession())
     {
-        KMessageBox::error(0, i18n("This session is already active in another running instance"));
+        QString errmsg = i18n("This session (%1) is already active in another running instance",
+                              sessionController->activeSession() ? sessionController->activeSession()->description() : "null" );
+        if( mode & Core::NoUi ) {
+            QTextStream qerr(stderr);
+            qerr << endl << errmsg << endl;
+        } else {
+            KMessageBox::error(0, errmsg);
+        }
         return false;
     }
+    // Initialize the item repository as first thing after loading the session,
+    // TODO: Is this early enough, or should we put the loading of the session into
+    // the controller construct
+    globalItemRepositoryRegistry();
     
     if(!(mode & Core::NoUi)) uiController->initialize();
     languageController->initialize();
@@ -224,13 +235,13 @@ CorePrivate::~CorePrivate()
 }
 
 
-bool Core::initialize(KSplashScreen* splash, Setup mode)
+bool Core::initialize(KSplashScreen* splash, Setup mode, const QString& session )
 {
     if (m_self)
         return true;
 
     m_self = new Core();
-    bool ret = m_self->d->initialize(mode);
+    bool ret = m_self->d->initialize(mode, session);
     if( splash ) {
         QTimer::singleShot( 200, splash, SLOT(deleteLater()) );
     }
