@@ -28,11 +28,11 @@
 #include <KDebug>
 #include <QAction>
 
-#include "documentationview.h"
-#include <language/interfaces/codecontext.h>
 #include <interfaces/contextmenuextension.h>
+#include <language/interfaces/codecontext.h>
 #include <language/duchain/duchain.h>
 #include <language/duchain/duchainlock.h>
+#include <documentation/documentationview.h>
 
 using namespace KDevelop;
 
@@ -121,14 +121,13 @@ KSharedPtr< KDevelop::IDocumentation > DocumentationController::documentationFor
 
 QList< IDocumentationProvider* > DocumentationController::documentationProviders() const
 {
-    QList<IPlugin*> plugins=ICore::self()->pluginController()->allPluginsForExtension(IDocumentationProvider_iid);
-    kDebug(9529) << "All plugins for" << IDocumentationProvider_iid << plugins;
+    QList<IPlugin*> plugins=ICore::self()->pluginController()->allPluginsForExtension("org.kdevelop.IDocumentationProvider");
     
     QList<IDocumentationProvider*> ret;
     
     foreach(IPlugin* p, plugins)
     {
-        IDocumentationProvider *doc=dynamic_cast<IDocumentationProvider*>(p);
+        IDocumentationProvider *doc=p->extension<IDocumentationProvider>();
         Q_ASSERT(doc);
         ret.append(doc);
     }
