@@ -36,7 +36,6 @@ Boston, MA 02110-1301, USA.
 #include <kstandardaction.h>
 #include <kmessagebox.h>
 #include <kxmlguiwindow.h>
-#include <kfiledialog.h>
 #include <kactioncollection.h>
 #include <ktemporaryfile.h>
 #include <kservicetypetrader.h>
@@ -79,12 +78,6 @@ Boston, MA 02110-1301, USA.
 namespace KDevelop
 {
 
-bool parseAllProjectSources()
-{
-    KConfigGroup group = Core::self()->activeSession()->config()->group( "Project Manager" );
-    return group.readEntry( "Parse All Project Sources", true );
-}
-
 class ProjectControllerPrivate
 {
 public:
@@ -97,6 +90,7 @@ public:
     QItemSelectionModel* selectionModel;
     QMap<IProject*, QPointer<KSettings::Dialog> > m_cfgDlgs;
     QPointer<KAction> m_openProject;
+    QPointer<KAction> m_fetchProject;
     QPointer<KAction> m_closeProject;
     QPointer<KAction> m_openConfig;
     IProjectDialogProvider* dialog;
@@ -144,7 +138,8 @@ public:
                                               << proj->developerTempFile()
                                               << proj->projectTempFile()
                                               << proj->projectFileUrl().url()
-                                              << proj->developerFileUrl().url() );
+                                              << proj->developerFileUrl().url()
+                                              << proj->name() );
         }
         m_configuringProject = proj;
         m_cfgDlgs[proj]->setWindowTitle( i18n("Configure Project %1", proj->name()) );
@@ -223,7 +218,50 @@ public:
         }
     
     }
+    
+    void importProject(const KUrl& url)
+    {
+        if ( !url.isValid() )
+        {
+            KMessageBox::error(Core::self()->uiControllerInternal()->activeMainWindow(),
+                            i18n("Invalid Location: %1", url.prettyUrl()));
+            return;
+        }
+        if ( m_currentlyOpening.contains(url))
+        {
+            kDebug() << "Already opening " << url << ". Aborting.";
+            KPassivePopup::message( i18n( "Project already being opened"), 
+                                    i18n( "Already opening %1, not opening again", 
+                                        url.prettyUrl() ), 
+                                    m_core->uiController()->activeMainWindow() );
+            return;
+        }
 
+        foreach( IProject* project, m_projects )
+        {
+            if ( url == project->projectFileUrl() )
+            {
+                if ( dialog->userWantsReopen() )
+                { // close first, then open again by falling through
+                    q->closeProject(project);
+                } else { // abort
+                    return;
+                }
+            }
+        }
+
+        m_core->pluginControllerInternal()->loadProjectPlugins();
+
+        Project* project = new Project();
+        emit q->projectAboutToBeOpened( project );
+        if ( !project->open( url ) )
+        {
+            delete project;
+            return;
+        }
+
+        m_currentlyOpening << url;
+    }
 
 };
 
@@ -263,10 +301,10 @@ bool projectFileExists( const KUrl& u )
     }
 }
 
-KUrl ProjectDialogProvider::askProjectConfigLocation(const KUrl& startUrl)
+KUrl ProjectDialogProvider::askProjectConfigLocation(bool fetch, const KUrl& startUrl)
 {
     Q_ASSERT(d);
-    OpenProjectDialog dlg( startUrl, Core::self()->uiController()->activeMainWindow() );
+    OpenProjectDialog dlg( fetch, startUrl, Core::self()->uiController()->activeMainWindow() );
     if(dlg.exec() == QDialog::Rejected)
         return KUrl();
     
@@ -352,10 +390,17 @@ void ProjectController::setupActions()
 
     d->m_openProject = action = ac->addAction( "project_open" );
     action->setText(i18n( "Open / Import Project..." ) );
-    connect( action, SIGNAL( triggered( bool ) ), SLOT( openProject() ) );
     action->setToolTip( i18n( "Open / Import Project" ) );
     action->setWhatsThis( i18n( "<b>Open / Import project</b><p>Open an existing KDevelop 4 project or import an existing Project into KDevelop 4. This entry allows to select a KDevelop4 project file or an existing directory to open it in KDevelop. When opening an existing directory that does not yet have a KDevelop4 project file, the file will be created.</p>" ) );
     action->setIcon(KIcon("project-open"));
+    connect( action, SIGNAL( triggered( bool ) ), SLOT( openProject() ) );
+    
+    d->m_fetchProject = action = ac->addAction( "project_fetch" );
+    action->setText(i18n( "Fetch Project..." ) );
+    action->setToolTip( i18n( "Fetch Project" ) );
+    action->setWhatsThis( i18n( "<b>Fetch project</b><p>Fetches a project from either a Version Control System or somewhere else and puts into the disk and lets </p>" ) );
+//     action->setIcon(KIcon("project-open"));
+    connect( action, SIGNAL( triggered( bool ) ), SLOT( fetchProject() ) );
 
 //    action = ac->addAction( "project_close" );
 //    action->setText( i18n( "C&lose Project" ) );
@@ -515,7 +560,7 @@ void ProjectController::openProjectForUrl(const KUrl& sourceUrl) {
             break;
     }
     
-    KUrl askForOpen = d->dialog->askProjectConfigLocation(dirUrl);
+    KUrl askForOpen = d->dialog->askProjectConfigLocation(false, dirUrl);
     
     if(askForOpen.isValid())
         openProject(askForOpen);
@@ -556,52 +601,23 @@ void ProjectController::openProject( const KUrl &projectFile )
     
     if ( url.isEmpty() )
     {
-        url = d->dialog->askProjectConfigLocation();
-        if ( url.isEmpty() )
-            return;
+        url = d->dialog->askProjectConfigLocation(false);
     }
 
-    if ( !url.isValid() )
+    if ( !url.isEmpty() )    
     {
-        KMessageBox::error(Core::self()->uiControllerInternal()->activeMainWindow(),
-                           i18n("Invalid Location: %1", url.prettyUrl()));
-        return;
+        d->importProject(url);
     }
-    if ( d->m_currentlyOpening.contains(url))
+}
+
+void ProjectController::fetchProject()
+{
+    KUrl url = d->dialog->askProjectConfigLocation(true);
+
+    if ( !url.isEmpty() )    
     {
-        kDebug() << "Already opening " << url << ". Aborting.";
-        KPassivePopup::message( i18n( "Project already being opened"), 
-                                i18n( "Already opening %1, not opening again", 
-                                      url.prettyUrl() ), 
-                                Core::self()->uiController()->activeMainWindow() );
-        return;
+        d->importProject(url);
     }
-
-    foreach( IProject* project, d->m_projects )
-    {
-        if ( url == project->projectFileUrl() )
-        {
-            if ( d->dialog->userWantsReopen() )
-            { // close first, then open again by falling through
-                closeProject(project);
-            } else { // abort
-                return;
-            }
-        }
-    }
-
-    d->m_core->pluginControllerInternal()->loadProjectPlugins();
-
-    Project* project = new Project();
-    emit projectAboutToBeOpened( project );
-    if ( !project->open( url ) )
-    {
-        delete project;
-        return;
-    }
-
-    d->m_currentlyOpening << url;
-    return;
 }
 
 void ProjectController::projectImportingFinished( IProject* project )
@@ -829,8 +845,8 @@ ContextMenuExtension ProjectController::contextMenuExtension ( Context* ctx )
     if ( ctx->type() != Context::ProjectItemContext || !static_cast<ProjectItemContext*>(ctx)->items().isEmpty() ) {
         return ext;
     }
-    
     ext.addAction(ContextMenuExtension::ProjectGroup, d->m_openProject);
+    ext.addAction(ContextMenuExtension::ProjectGroup, d->m_fetchProject);
     ext.addAction(ContextMenuExtension::ProjectGroup, d->m_recentAction);
     return ext;
 }
