@@ -71,6 +71,7 @@ public:
         desired["org.kdevelop.ContextBrowser"] = Sublime::Bottom;
         desired["org.kdevelop.KonsoleView"] = Sublime::Bottom;
         desired["org.kdevelop.SnippetView"] = Sublime::Right;
+        desired["org.kdevelop.ExternalScriptView"] = Sublime::Right;
         Sublime::Area* a =
             new Sublime::Area(m_controller, "code", i18n("Code"));
         a->setDesiredToolViews(desired);
@@ -275,6 +276,8 @@ QWidget* UiController::findToolView(const QString& name, IToolViewFactory *facto
         }
     }
     
+    QWidget* ret = 0;
+    
     if(flags & Create)
     {
         if(!d->factoryDocuments.contains(factory))
@@ -282,13 +285,29 @@ QWidget* UiController::findToolView(const QString& name, IToolViewFactory *facto
         
         Sublime::ToolDocument *doc = d->factoryDocuments[factory];
 
-        addToolViewToArea(factory, doc, activeArea());
+        Sublime::View* view = addToolViewToArea(factory, doc, activeArea());
+        if(view)
+            ret = view->widget();
         
         if(flags & Raise)
             findToolView(name, factory, Raise);
     }
 
-    return 0;
+    return ret;
+}
+
+void UiController::raiseToolView(QWidget* toolViewWidget)
+{
+    if(!d->areasRestored)
+        return;
+
+    QList< Sublime::View* > views = activeArea()->toolViews();
+    foreach(Sublime::View* view, views) {
+        if(view->widget() == toolViewWidget) {
+            view->requestRaise();
+            return;
+        }
+    }
 }
 
 void UiController::addToolView(const QString & name, IToolViewFactory *factory)
