@@ -85,7 +85,7 @@ void WorkingSetController::initialize()
 {
     //Load all working-sets
     KConfigGroup setConfig(Core::self()->activeSession()->config(), "Working File Sets");
-    foreach(QString set, setConfig.groupList())
+    foreach(const QString& set, setConfig.groupList())
     {
         if(setConfig.hasKey("iconName"))
             getWorkingSet(set, setConfig.group(set).readEntry<QString>("iconName", QString()));
@@ -96,6 +96,15 @@ void WorkingSetController::initialize()
 
 void WorkingSetController::cleanup()
 {
+    foreach(Sublime::MainWindow* window, Core::self()->uiControllerInternal()->mainWindows()) {
+        foreach (Sublime::Area *area, window->areas()) {
+            if (!area->workingSet().isEmpty()) {
+                Q_ASSERT(m_workingSets.contains(area->workingSet()));
+                m_workingSets[area->workingSet()]->saveFromArea(area, area->rootIndex());
+            }
+        }
+    }
+
     foreach(WorkingSet* set, m_workingSets) {
         kDebug() << "set" << set->id() << "persistent" << set->isPersistent() << "has areas:" << set->hasConnectedAreas() << "files" << set->fileList();
         if(!set->isPersistent() && !set->hasConnectedAreas()) {
@@ -158,12 +167,12 @@ WorkingSet* WorkingSetController::getWorkingSet(QString id, QString icon)
 
 void deleteGroupRecursive(KConfigGroup group) {
 //     kDebug() << "deleting" << group.name();
-    foreach(QString entry, group.entryMap().keys()) {
+    foreach(const QString& entry, group.entryMap().keys()) {
         group.deleteEntry(entry);
     }
     Q_ASSERT(group.entryMap().isEmpty());
 
-    foreach(QString subGroup, group.groupList()) {
+    foreach(const QString& subGroup, group.groupList()) {
         deleteGroupRecursive(group.group(subGroup));
         group.deleteGroup(subGroup);
     }
@@ -185,6 +194,11 @@ void WorkingSet::saveFromArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex
     KConfigGroup group = setConfig.group(m_id);
     group.writeEntry("iconName", m_iconName);
     deleteGroupRecursive(group);
+    if (area->activeView()) {
+        group.writeEntry("Active View", area->activeView()->document()->documentSpecifier());
+    } else {
+        group.writeEntry("Active View", QString());
+    }
     saveFromArea(area, areaIndex, group);
 
     if(isEmpty())
@@ -216,6 +230,7 @@ void WorkingSet::saveFromArea(Sublime::Area* a, Sublime::AreaIndex * area, KConf
 
         int index = 0;
         foreach (Sublime::View* view, area->views()) {
+            kDebug() << view->document()->title();
             group.writeEntry(QString("View %1 Type").arg(index), view->document()->documentType());
             group.writeEntry(QString("View %1").arg(index), view->document()->documentSpecifier());
 
@@ -339,12 +354,23 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex,
 
     loadToArea(area, areaIndex, group);
 
-    //activate first view in the working set
+    //activate view in the working set
     if (!area->views().isEmpty()) {
         foreach(Sublime::MainWindow* window, Core::self()->uiControllerInternal()->mainWindows()) {
             if(window->area() == area) {
                 window->setArea(area);
-                window->activateView(area->views().first());
+                QString activeView = group.readEntry("Active View", QString());
+                kDebug() << activeView;
+                bool found = false;
+                foreach (Sublime::View *v, area->views()) {
+                    if (v->document()->documentSpecifier() == activeView) {
+                        window->activateView(v);
+                        found = true;
+                        break;
+                    }
+                }
+                if (!found) window->activateView(area->views().first()); //fallback
+                break;
             }
         }
     }
@@ -398,6 +424,7 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex,
                              KTextEditor::Cursor::invalid(), IDocumentController::DoNotActivate | IDocumentController::DoNotCreateView);
             Sublime::Document *document = dynamic_cast<Sublime::Document*>(doc);
             if (document) {
+                kDebug() << document->title();
                 Sublime::View* view = document->createView();
 
                 QString state = group.readEntry(QString("View %1 State").arg(i), "");
@@ -522,7 +549,7 @@ void WorkingSetToolButton::subtractSet()
 void WorkingSetToolButton::mergeSet()
 {
     QSet< QString > loadFiles = m_set->fileList().toSet() - Core::self()->workingSetControllerInternal()->getWorkingSet(mainWindow()->area()->workingSet())->fileList().toSet();
-    foreach(QString file, loadFiles)
+    foreach(const QString& file, loadFiles)
         Core::self()->documentController()->openDocument(file);
 }
 
@@ -548,6 +575,7 @@ void WorkingSetToolButton::loadSet()
 void WorkingSetToolButton::closeSet()
 {
     m_set->setPersistent(true);
+    m_set->saveFromArea(mainWindow()->area(), mainWindow()->area()->rootIndex());
 
     if(!Core::self()->documentControllerInternal()->saveAllDocumentsForWindow(mainWindow(), KDevelop::IDocument::Default))
         return;
@@ -636,6 +664,7 @@ void WorkingSet::changingWorkingSet(Sublime::Area* area, QString from, QString t
     if (from == to)
         return;
     Q_ASSERT(m_areas.contains(area));
+    if (!m_id.isEmpty()) saveFromArea(area, area->rootIndex());
     disconnectArea(area);
     WorkingSet* newSet = Core::self()->workingSetControllerInternal()->getWorkingSet(to);
     newSet->connectArea(area);
@@ -706,15 +735,9 @@ WorkingSet::WorkingSet(QString id, QString icon) : m_id(id), m_iconName(icon) {
 }
 
 WorkingSetToolTipWidget::WorkingSetToolTipWidget(QWidget* parent, WorkingSet* set, MainWindow* mainwindow) : QWidget(parent), m_set(set) {
-    QFrame* frame = new QFrame(this);
-    frame->setFrameStyle(QFrame::Panel | QFrame::Plain);
-    frame->setLineWidth(1);
     QVBoxLayout* layout = new QVBoxLayout(this);
+    layout->setSpacing(0);
     layout->setMargin(0);
-    layout->addWidget(frame);
-    QVBoxLayout* layout2 = new QVBoxLayout(frame);
-    layout2->setSpacing(0);
-    layout2->setContentsMargins(0, 0, 0, 0);
 
     // title bar
     {
@@ -743,12 +766,12 @@ WorkingSetToolTipWidget::WorkingSetToolTipWidget(QWidget* parent, WorkingSet* se
         connect(m_deleteButton, SIGNAL(clicked(bool)), m_set, SLOT(deleteSet()));
         connect(m_deleteButton, SIGNAL(clicked(bool)), this, SIGNAL(shouldClose()));
         topLayout->addWidget(m_deleteButton);
-        layout2->addLayout(topLayout);
+        layout->addLayout(topLayout);
         // horizontal line
         QFrame* line = new QFrame();
         line->setFrameShape(QFrame::HLine);
         line->setFrameShadow(QFrame::Raised);
-        layout2->addWidget(line);
+        layout->addWidget(line);
     }
 
     // everything else is added to the following widget which just has a different background color
@@ -756,13 +779,7 @@ WorkingSetToolTipWidget::WorkingSetToolTipWidget(QWidget* parent, WorkingSet* se
     {
         QWidget* body = new QWidget();
         body->setLayout(bodyLayout);
-        QPalette palette = body->palette();
-        QColor bgColor = palette.color(QPalette::Background);
-        bgColor.setAlpha(0.4*255);
-        palette.setColor(QPalette::Background, bgColor);
-        body->setPalette(palette);
-        body->setAutoFillBackground(true);
-        layout2->addWidget(body);
+        layout->addWidget(body);
     }
 
     // document list actions
@@ -790,15 +807,10 @@ WorkingSetToolTipWidget::WorkingSetToolTipWidget(QWidget* parent, WorkingSet* se
         connect(m_subtractButton, SIGNAL(clicked(bool)), m_setButton, SLOT(subtractSet()));
         actionsLayout->addWidget(m_subtractButton);
         bodyLayout->addLayout(actionsLayout);
-        // horizontal line
-        QFrame* line = new QFrame();
-        line->setFrameShape(QFrame::HLine);
-        line->setFrameShadow(QFrame::Sunken);
-        bodyLayout->addWidget(line);
     }
 
     QStringList files = m_set->fileList();
-    foreach(QString file, files) {
+    foreach(const QString& file, files) {
         QHBoxLayout* fileLayout = new QHBoxLayout;
 
         QToolButton* plusButton = new QToolButton;
