@@ -5,6 +5,7 @@
  *                                                                         *
  *   Adapted for DVCS                                                      *
  *   Copyright 2008 Evgeniy Ivanov <powerfox@kde.ru>                       *
+ *   Copyright Aleix Pol Gonzalez <aleixpol@kde.org>                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or         *
  *   modify it under the terms of the GNU General Public License as        *
@@ -29,40 +30,53 @@
 #include <QtCore/QFileInfo>
 #include <QtCore/QList>
 #include <QtCore/QStringList>
+#include <QtCore/QDir>
+#include <QtGui/QStandardItemModel>
 
 #include <KDE/KDebug>
 #include <KDE/KLocale>
+#include <KDE/KUrl>
 
 #include <interfaces/iplugin.h>
-#include <QDir>
+#include <outputview/outputmodel.h>
+
+using namespace KDevelop;
 
 struct DVcsJobPrivate
 {
-    DVcsJobPrivate() : childproc(new KProcess), commMode(KProcess::SeparateChannels), vcsplugin(0)
-    {
-        isRunning = failed = wasStarted = false;
-    }
+    DVcsJobPrivate() : childproc(new KProcess), vcsplugin(0)
+    {}
 
     ~DVcsJobPrivate() {
         delete childproc;
     }
 
     KProcess*   childproc;
-    QStringList command;
-    QString     server;
-    QDir        directory;
-    bool        isRunning;
-    bool        wasStarted;
-    bool        failed;
+    VcsJob::JobStatus status;
     QByteArray  output;
-    KProcess::OutputChannelMode commMode;
-    KDevelop::IPlugin* vcsplugin;
+    IPlugin* vcsplugin;
+    
+    QVariant results;
+    OutputModel* model;
 };
 
-DVcsJob::DVcsJob(KDevelop::IPlugin* parent, KDevelop::OutputJob::OutputJobVerbosity verbosity)
+DVcsJob::DVcsJob(const QDir& workingDir, IPlugin* parent, OutputJob::OutputJobVerbosity verbosity)
     : VcsJob(parent, verbosity), d(new DVcsJobPrivate)
 {
+    d->status = JobNotStarted;
     d->vcsplugin = parent;
+    d->childproc->setWorkingDirectory(workingDir.absolutePath());
+    d->model = new OutputModel;
+    setModel(d->model, IOutputView::TakeOwnership);
+    
+    connect(d->childproc, SIGNAL(finished(int, QProcess::ExitStatus)),
+            SLOT(slotProcessExited(int, QProcess::ExitStatus)));
+    connect(d->childproc, SIGNAL(error( QProcess::ProcessError )),
+            SLOT(slotProcessError(QProcess::ProcessError)));
+
+    connect(d->childproc, SIGNAL(readyReadStandardOutput()),
+                SLOT(slotReceivedStdout()));
+    
 }
 
 DVcsJob::~DVcsJob()
@@ -70,70 +84,39 @@ DVcsJob::~DVcsJob()
     delete d;
 }
 
-void DVcsJob::clear()
+QDir DVcsJob::directory() const
 {
-    //Do not use KProcess::clearEnvironment() (it sets the environment to kde_dummy).
-    //Also DVCSjob can't set it, so it's ok.
-    d->command.clear();
-    d->output.clear();
-    d->server.clear();
-    d->directory = QDir::temp();
-    d->isRunning = d->failed = d->wasStarted = false;
-}
-
-void DVcsJob::setServer(const QString& server)
-{
-    d->server = server;
-}
-
-void DVcsJob::setDirectory(const QDir& directory)
-{
-    d->directory = directory;
-}
-
-void DVcsJob::setStandardInputFile(const QString &fileName)
-{
-    d->childproc->setStandardInputFile(fileName);
-}
-
-const QDir & DVcsJob::getDirectory() const
-{
-    return d->directory;
-}
-
-bool DVcsJob::isRunning() const
-{
-    return d->isRunning;
+    return QDir(d->childproc->workingDirectory());
 }
 
 DVcsJob& DVcsJob::operator<<(const QString& arg)
 {
-    d->command.append( arg );
+    *d->childproc << arg;
     return *this;
 }
 
 DVcsJob& DVcsJob::operator<<(const char* arg)
 {
-    d->command.append( arg );
+    *d->childproc << arg;
     return *this;
 }
 
 DVcsJob& DVcsJob::operator<<(const QStringList& args)
 {
-    d->command << args;
+    *d->childproc << args;
     return *this;
 }
 
-QString DVcsJob::dvcsCommand() const
+QStringList DVcsJob::dvcsCommand() const
 {
-    return d->command.join(" ");
+    return d->childproc->program();
 }
 
 QString DVcsJob::output() const
 {
     QByteArray stdoutbuf = rawOutput();
     int endpos = stdoutbuf.size();
-    if (isRunning()) {    // We may have received only part of a code-point
+    if (d->status==JobRunning) {    // We may have received only part of a code-point. apol: ASSERT?
         endpos = stdoutbuf.lastIndexOf('\n')+1; // Include the final newline or become 0, when there is no newline
     }
 
@@ -147,64 +130,53 @@ QByteArray DVcsJob::rawOutput() const
 
 void DVcsJob::setResults(const QVariant &res)
 {
-    results = res;
+    d->results = res;
 }
 
 QVariant DVcsJob::fetchResults()
 {
-    return results;
-}
-
-void DVcsJob::setExitStatus(const bool exitStatus)
-{
-    d->failed = exitStatus;
+    return d->results;
 }
 
 void DVcsJob::start()
 {
-    Q_ASSERT_X(!d->isRunning, "DVCSjob::start", "Another proccess was started using this job class");
-    d->wasStarted = true;
+    Q_ASSERT_X(!d->status==JobRunning, "DVCSjob::start", "Another proccess was started using this job class");
 
-#if 0
-    //do not allow to run commands in the application's working dir
-    //TODO: change directory to KUrl, check if it's a relative path
-    if(d->directory.isEmpty() ) 
-    {
-        kDebug() << "No working directory specified for DVCS command";
-        slotProcessError(QProcess::UnknownError);
+    const QDir& workingdir = directory();
+    if( !workingdir.exists() ) {
+        QString error = i18n( "Working Directory doesn't exist: %1", d->childproc->workingDirectory() );
+        d->model->appendLine(error);
+        setError( 255 );
+        setErrorText(error);
+        return;
+    }
+    if( !workingdir.isAbsolute() ) {
+        QString error = i18n( "Working Directory is not absolute: %1", d->childproc->workingDirectory() );
+        d->model->appendLine(error);
+        setError( 255 );
+        setErrorText(error);
         return;
     }
-#endif
-    const QString workingDirectory = d->directory.absolutePath();
-    kDebug() << "Working directory:" << workingDirectory;
-    d->childproc->setWorkingDirectory(workingDirectory);
-
-
-    connect(d->childproc, SIGNAL(finished(int, QProcess::ExitStatus)),
-            SLOT(slotProcessExited(int, QProcess::ExitStatus)));
-    connect(d->childproc, SIGNAL(error( QProcess::ProcessError )),
-            SLOT(slotProcessError(QProcess::ProcessError)));
-
-    connect(d->childproc, SIGNAL(readyReadStandardError()),
-                SLOT(slotReceivedStderr()));
-    connect(d->childproc, SIGNAL(readyReadStandardOutput()),
-                SLOT(slotReceivedStdout()));
 
     kDebug() << "Execute dvcs command:" << dvcsCommand();
 
-    d->output.clear();
-    d->isRunning = true;
-    d->childproc->setOutputChannelMode( d->commMode );
-    d->childproc->setProgram( d->command );
+    QString service;
+    if(d->vcsplugin)
+        service = d->vcsplugin->objectName();
+    setObjectName(service+": "+dvcsCommand().join(" "));
+    
+    d->status = JobRunning;
     d->childproc->setEnvironment(QProcess::systemEnvironment());
+    d->childproc->setOutputChannelMode(KProcess::SeparateChannels);
     //the started() and error() signals may be delayed! It causes crash with deferred deletion!!!
-    d->childproc->waitForStarted();
     d->childproc->start();
+    
+    d->model->appendLine(directory().path() + "> " + dvcsCommand().join(" "));
 }
 
 void DVcsJob::setCommunicationMode(KProcess::OutputChannelMode comm)
 {
-    d->commMode = comm;
+    d->childproc->setOutputChannelMode(comm);
 }
 
 void DVcsJob::cancel()
@@ -214,13 +186,7 @@ void DVcsJob::cancel()
 
 void DVcsJob::slotProcessError( QProcess::ProcessError err )
 {
-    // disconnect all connections to childproc's signals; they are no longer needed
-    d->childproc->disconnect();
-
-    d->isRunning = false;
-
-    //NOTE: some DVCS commands can use stderr...
-    d->failed = true;
+    d->status = JobFailed;
 
     //Do not use d->childproc->exitCode() to set an error! If we have FailedToStart exitCode will return 0,
     //and if exec is used, exec will return true and that is wrong!
@@ -242,7 +208,7 @@ void DVcsJob::slotProcessError( QProcess::ProcessError err )
         errorValue = "Timedout";
         break;
     case QProcess::WriteError:
-        errorValue = "WriteErro";
+        errorValue = "WriteError";
         break;
     case QProcess::ReadError:
         errorValue = "ReadError";
@@ -253,51 +219,66 @@ void DVcsJob::slotProcessError( QProcess::ProcessError err )
     }
     kDebug() << "oops, found an error while running" << dvcsCommand() << ":" << errorValue 
                                                      << "Exit code is:" << d->childproc->exitCode();
+    
+    displayOutput(d->childproc->readAllStandardError());
+    d->model->appendLine(i18n("Command finnished with error %1.", errorValue));
+    
+    //Even if it was a silent process we want to provide some feedback to the user about what went wrong
+    //so we show the output then.
+    if(verbosity()==Silent)
+        startOutput();
     jobIsReady();
 }
 
 void DVcsJob::slotProcessExited(int exitCode, QProcess::ExitStatus exitStatus)
 {
-    // disconnect all connections to childproc's signals; they are no longer needed
-    d->childproc->disconnect();
-
-    d->isRunning = false;
+    d->status = JobSucceeded;
 
     if (exitStatus != QProcess::NormalExit || exitCode != 0)
         slotProcessError(QProcess::UnknownError);
 
-    kDebug() << "process has finished with no errors";
+    d->model->appendLine(i18n("Command exited with value %1.", exitCode));
     jobIsReady();
 }
 
+void DVcsJob::displayOutput(const QString& data)
+{
+    d->model->appendLines(data.split('\n'));
+}
+
 void DVcsJob::slotReceivedStdout()
 {
+    QByteArray output = d->childproc->readAllStandardOutput();
+    
     // accumulate output
-    d->output.append(d->childproc->readAllStandardOutput());
+    d->output.append(output);
+    
+    displayOutput(output);
 }
 
-void DVcsJob::slotReceivedStderr()
+VcsJob::JobStatus DVcsJob::status() const
 {
-    // accumulate output
-    d->output.append(d->childproc->readAllStandardError());
+    return d->status;
 }
 
-KDevelop::VcsJob::JobStatus DVcsJob::status() const
-{
-    if (!d->wasStarted)
-        return KDevelop::VcsJob::JobNotStarted;
-    if (d->failed)
-        return KDevelop::VcsJob::JobFailed;
-    if (d->isRunning)
-        return KDevelop::VcsJob::JobRunning;
-    return KDevelop::VcsJob::JobSucceeded;
-}
-
-KDevelop::IPlugin* DVcsJob::vcsPlugin() const
+IPlugin* DVcsJob::vcsPlugin() const
 {
     return d->vcsplugin;
 }
 
+DVcsJob& DVcsJob::operator<<(const KUrl& url)
+{
+    *d->childproc << url.toLocalFile();
+    return *this;
+}
+
+DVcsJob& DVcsJob::operator<<(const QList< KUrl >& urls)
+{
+    foreach(const KUrl &url, urls)
+        operator<<(url);
+    return *this;
+}
+
 void DVcsJob::jobIsReady()
 {
     emit readyForParsing(this); //let parsers to set status
@@ -305,4 +286,4 @@ void DVcsJob::jobIsReady()
     emit resultsReady(this); //VcsJob
 }
 
-KProcess* DVcsJob::getChildproc() {return d->childproc;}
+KProcess* DVcsJob::process() {return d->childproc;}
