@@ -5,6 +5,7 @@
  *                                                                         *
  *   Adapted for DVCS                                                      *
  *   Copyright 2008 Evgeniy Ivanov <powerfox@kde.ru>                       *
+ *   Copyright 2010 Aleix Pol Gonzalez <aleixpol@kde.org>                  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or         *
  *   modify it under the terms of the GNU General Public License as        *
@@ -39,87 +40,61 @@ class DVcsJobPrivate;
 
 /**
  * This class is capable of running our dvcs commands. 
- * Most of all DVCSjobs are created in DVCS executors, but executed in DistributedVersionControlPlugin or 
+ * Most of all DVcsJob are created in DVCS executors, but executed in DistributedVersionControlPlugin or
  * any managers like BranchManager.
- * @note Connect to Kjob::result(KJob*) to be notified when the job finished.
+ * @note Connect to KJob::result(KJob*) to be notified when the job finished.
  * 
- * How to create DVCSjob:
+ * How to create DVcsJob:
  * @code
- * DVCSjob* job = new DVCSjob(vcsplugin);
- * if (job)
- * {
- *     job->setDirectory(workDir);
- *     *job << "git-rev-parse";
- *     foreach(const QString &arg, args) // *job << args can be used instead!
+ * DVcsJob* job = new DVcsJob(vcsplugin);
+ * 
+ * job->setDirectory(workDir);
+ * *job << "git-rev-parse";
+ * foreach(const QString &arg, args) // *job << args can be used instead!
  *     *job << arg;
- *     return job;
- * }
- * if (job) delete job;
- * return NULL;
+ * return job;
+ * 
+ * return error_cmd(i18n("could not create the job"));
  * @endcode
  * 
  * Usage example 1:
  * @code
- * VcsJob* j = add(DistributedVersionControlPlugin::d->m_ctxUrlList, IBasicVersionControl::Recursive);
- * DVCSjob* job = dynamic_cast<DVCSjob*>(j);
- * if (job) {
- *     connect(job, SIGNAL(result(KJob*) ),
- *             this, SIGNAL(jobFinished(KJob*) ));
- *     job->start();
- * }
+ * VcsJob* j = add(KUrl::List() << a << b << c, IBasicVersionControl::Recursive);
+ * DVcsJob* job = qobject_cast<DVCSjob*>(j);
+ * connect(job, SIGNAL(result(KJob*) ),
+ *         this, SIGNAL(jobFinished(KJob*) ));
+ * ICore::self()->runController()->registerJob(job);
  * @endcode
  * 
- * Usage example 2:
+ * Usage example 2, asyunchronous:
  * @code
- * DVCSjob *branchJob = d->branch(repo, baseBranch, newBranch);
- * DVCSjob* job = gitRevParse(dirPath.toLocalFile(), QStringList(QString("--is-inside-work-tree")));
- * if (job)
- * {
- *     job->exec();
- *     if (job->status() == KDevelop::VcsJob::JobSucceeded)
- *         return true;
- *     else
- *     //something, mabe even just
- *         return false
- * }
+ * DVcsJob* branchJob = d->branch(repo, baseBranch, newBranch);
+ * 
+ * if (job->exec() && job->status() == KDevelop::VcsJob::JobSucceeded)
+ *     return true;
+ * else
+ *     //something, maybe even just
+ *     return false
  * @endcode
  * 
  * @author Robert Gruber <rgruber@users.sourceforge.net>
  * @author Evgeniy Ivanov <powerfox@kde.ru>
  */
+
+namespace KDevelop
+{
+
 class KDEVPLATFORMVCS_EXPORT DVcsJob : public KDevelop::VcsJob
 {
     Q_OBJECT
 public:
-    DVcsJob(KDevelop::IPlugin* parent, KDevelop::OutputJob::OutputJobVerbosity verbosity = KDevelop::OutputJob::Verbose);
+    DVcsJob(const QDir& workingDir, KDevelop::IPlugin* parent=0, KDevelop::OutputJob::OutputJobVerbosity verbosity = KDevelop::OutputJob::Verbose);
     virtual ~DVcsJob();
 
-    /**
-     * Call this method to clear the job (for example, before setting another job).
-     */
-    void clear();
-
-    /**
-     * It's not used in any DVCS plugin.
-     */
-    void setServer(const QString& server);
-
-    /**
-     * Sets working directory.
-     * @param directory Should contain only absolute path. Relative path or "" (working dir) are deprecated and will make job failed.
-     * @note In DVCS plugins directory variable is used to get relative pathes.
-     */
-    void setDirectory(const QDir & directory);
-
-    /**
-     * Sets standart Input file.
-     */
-    void setStandardInputFile(const QString &fileName);
-
     /**
      * Returns current working directory.
      */
-    QDir const & getDirectory() const;
+    QDir directory() const;
 
     /**
      * Call this method to set command to execute and its arguments.
@@ -138,28 +113,39 @@ public:
      * @see operator<<(const QString& arg).
      */
     DVcsJob& operator<<(const QStringList& args);
+    
+    /**
+     * Overloaded operator << for url's, can be used to pass files and
+     * makes arguments absolute to the process working directory
+     */
+    DVcsJob& operator<<(const KUrl& arg);
+    
+    /**
+     * @see operator<<(const KUrl& arg).
+     */
+    DVcsJob& operator<<(const QList<KUrl>& args);
 
     /**
-     * Call this mehod to start this job.
-     * @note Default communiaction mode is KProcess::AllOutput.
+     * Call this method to start this job.
+     * @note Default communication mode is KProcess::AllOutput.
      * @see Use setCommunicationMode() to override the default communication mode.
      */
     virtual void start();
 
     /**
-     * In some cases it's needed to specify the communisation mode between the
+     * In some cases it's needed to specify the communication mode between the
      * process and the job object. This is for instance done for the "git status"
-     * command. If stdout and stderr are processed as separate streams their signals
-     * do not always get emmited in correct order by KProcess. Which will lead to a
+     * command. If stdout and stderr are processed as separate streams, their signals
+     * do not always get emitted in correct order by KProcess, which will lead to a
      * screwed up output.
-     * @note Default communiaction mode is KProcess::SeparateChannels.
+     * @note Default communication mode is KProcess::SeparateChannels.
      */
     void setCommunicationMode(KProcess::OutputChannelMode comm);
 
     /**
      * @return The command that is executed when calling start().
      */
-    QString dvcsCommand() const;
+    QStringList dvcsCommand() const;
 
     /**
      * @return The whole output of the job as a string. (Might fail on binary data)
@@ -174,7 +160,7 @@ public:
     // Begin:  KDevelop::VcsJob
 
     /** 
-     * Sets executions reults.
+     * Sets executions results.
      * In most cases this method is used by IDVCSexecutor
      * @see fetchResults()
      */
@@ -187,15 +173,6 @@ public:
      */
     virtual QVariant fetchResults();
 
-    /**
-     * Sets exit status (d->failed variable).
-     * Since only executors can parse the job to set result, they can connect parsers to readyForParsing(DVCSjob) using
-     * Qt::DirectConnection to set the result. For example git-status can return exit status 1 
-     * if you don't set exit status in your parser then you will have JobFailes in status() result.
-     * @note First result is set in slotProcessExited() or slotProcessError().
-     */
-    virtual void setExitStatus(const bool exitStatus);
-
     /**
      * Returns JobStatus
      * @see KDevelop::VcsJob::JobStatus
@@ -208,7 +185,9 @@ public:
     virtual KDevelop::IPlugin* vcsPlugin() const;
     // End:  KDevelop::VcsJob
     
-    KProcess *getChildproc();
+    KProcess *process();
+    
+    void displayOutput(const QString& output);
 
 public Q_SLOTS:
     /**
@@ -216,24 +195,20 @@ public Q_SLOTS:
      */
     void cancel();
 
-    /**
-     * Returns if the job is running.
-     */
-    bool isRunning() const;
-
 Q_SIGNALS:
-    void readyForParsing(DVcsJob *job);
+    void readyForParsing(KDevelop::DVcsJob *job);
 
 private Q_SLOTS:
     void slotProcessError( QProcess::ProcessError );
     void slotProcessExited(int exitCode, QProcess::ExitStatus exitStatus);
     void slotReceivedStdout();
-    void slotReceivedStderr();
 
 private:
+    
     void jobIsReady();
     DVcsJobPrivate* const d;
-    QVariant results;
 };
 
+}
+
 #endif
