@@ -23,19 +23,18 @@
 
 #include <QtGui/QStringListModel>
 #include <KDE/KDialog>
+#include <QStandardItemModel>
 
-#include "ui_branchmanager.h"
-
-///TODO: maybe KDevelop's progressBar?
-
+class BranchesListModel;
 class KJob;
+namespace Ui { class BranchDialogBase; }
 
 namespace KDevelop
 {
     class DistributedVersionControlPlugin;
 }
 
-class BranchManager : public KDialog, public Ui::BranchDialogBase
+class BranchManager : public KDialog
 {
     Q_OBJECT
 public:
@@ -47,18 +46,37 @@ signals:
 
 private slots:
     void createBranch();
-    void renameBranch(QListWidgetItem * item);
     void delBranch();
     void checkoutBranch();
 
-    void currentActivatedData(QListWidgetItem * item);
-    void activateButtons(const QItemSelection&, const QItemSelection&);
-
 private:
     QString repo;
-    QString lastActivated;
     KDevelop::DistributedVersionControlPlugin* d;
 
+    Ui::BranchDialogBase* m_ui;
+    BranchesListModel* m_model;
+    
 };
 
+class BranchesListModel : public QStandardItemModel
+{
+    Q_OBJECT
+    public:
+        BranchesListModel(KDevelop::DistributedVersionControlPlugin* dvcsplugin, const QString& repo, QObject* parent = 0);
+        
+        void createBranch(const QString& baseBranch, const QString& newBranch);
+        void removeBranch(const QString& branch);
+        
+        KDevelop::DistributedVersionControlPlugin* dvcsPlugin() const { return dvcsplugin; }
+        QString repository() const { return repo; }
+        
+    public slots:
+        void resetCurrent();
+        
+    private:
+        KDevelop::DistributedVersionControlPlugin* dvcsplugin;
+        QString repo;
+};
+
+
 #endif
