@@ -108,6 +108,16 @@ struct VcsPluginHelper::VcsPluginHelperPrivate {
         connect(annotationAction, SIGNAL(triggered()), parent, SLOT(annotation()));
     }
     
+    bool allLocalFiles(const KUrl::List& urls)
+    {
+        bool ret=true;
+        foreach(const KUrl& url, urls) {
+            QFileInfo info(url.toLocalFile());
+            ret &= info.isFile();
+        }
+        return ret;
+    }
+    
     QMenu* createMenu()
     {
         bool allVersioned=true;
@@ -136,7 +146,7 @@ struct VcsPluginHelper::VcsPluginHelperPrivate {
         
         const bool singleVersionedFile = ctxUrls.count() == 1 && allVersioned;
         historyAction->setEnabled(singleVersionedFile);
-        annotationAction->setEnabled(singleVersionedFile);
+        annotationAction->setEnabled(singleVersionedFile && allLocalFiles(ctxUrls));
         diffToHeadAction->setEnabled(singleVersionedFile);
         diffToBaseAction->setEnabled(singleVersionedFile);
         commitAction->setEnabled(singleVersionedFile);
@@ -160,25 +170,6 @@ VcsPluginHelper::VcsPluginHelper(KDevelop::IPlugin* parent, KDevelop::IBasicVers
 VcsPluginHelper::~VcsPluginHelper()
 {}
 
-KUrl VcsPluginHelper::urlForItem(KDevelop::ProjectBaseItem* item) const
-{
-    if (item->file()) {
-        return item->file()->url();
-    }
-
-    if (item->folder()) {
-        return item->folder()->url();
-    }
-
-    KDevelop::ProjectBaseItem* parentitem = dynamic_cast<KDevelop::ProjectBaseItem*>(item->parent());
-
-    if (parentitem) {
-        return parentitem->folder()->url();
-    }
-
-    return KUrl();
-}
-
 void VcsPluginHelper::setupFromContext(Context* context)
 {
     d->ctxUrls.clear();
@@ -187,7 +178,8 @@ void VcsPluginHelper::setupFromContext(Context* context)
 
         if (prjctx) {
             foreach(KDevelop::ProjectBaseItem* item, prjctx->items()) {
-                d->ctxUrls.append(urlForItem(item));
+                if(!item->target())
+                    d->ctxUrls.append(item->url());
             }
         }
     }
@@ -244,6 +236,7 @@ void VcsPluginHelper::revert()
 void VcsPluginHelper::diffToHead()
 {
     SINGLEURL_SETUP_VARS
+    ICore::self()->documentController()->saveAllDocuments();
     KDevelop::VcsJob* job = iface->diff(url,
                                         KDevelop::VcsRevision::createSpecialRevision(KDevelop::VcsRevision::Head),
                                         KDevelop::VcsRevision::createSpecialRevision(KDevelop::VcsRevision::Working));
@@ -252,42 +245,30 @@ void VcsPluginHelper::diffToHead()
     d->plugin->core()->runController()->registerJob(job);
 }
 
-QStringList locationListToString(const QList<VcsLocation>& locations)
-{
-    QStringList ret;
-    foreach(const VcsLocation& loc, locations) {
-        ret.append(loc.localUrl().prettyUrl());
-    }
-    return ret;
-}
-
 void VcsPluginHelper::diffJobFinished(KJob* job)
 {
-    KDevelop::VcsJob* vcsjob = dynamic_cast<KDevelop::VcsJob*>(job);
+    KDevelop::VcsJob* vcsjob = qobject_cast<KDevelop::VcsJob*>(job);
     Q_ASSERT(vcsjob);
 
-    if (vcsjob) {
-        if (vcsjob->status() == KDevelop::VcsJob::JobSucceeded) {
-            KDevelop::VcsDiff d = vcsjob->fetchResults().value<KDevelop::VcsDiff>();
-            if(d.isEmpty())
-                KMessageBox::error(ICore::self()->uiController()->activeMainWindow(),
-                                   i18n("Cannot show the differences because there were none."),
-                                   i18n("VCS support"));
-            else {
-                VCSDiffPatchSource* patch=new VCSDiffPatchSource(d);
-                showVcsDiff(patch);
-            }
-        } else {
-            KMessageBox::error(ICore::self()->uiController()->activeMainWindow(), vcsjob->errorString(), i18n("Unable to get difference."));
+    if (vcsjob->status() == KDevelop::VcsJob::JobSucceeded) {
+        KDevelop::VcsDiff d = vcsjob->fetchResults().value<KDevelop::VcsDiff>();
+        if(d.isEmpty())
+            KMessageBox::error(ICore::self()->uiController()->activeMainWindow(),
+                                i18n("Cannot show the differences because there were none."),
+                                i18n("VCS support"));
+        else {
+            VCSDiffPatchSource* patch=new VCSDiffPatchSource(d);
+            showVcsDiff(patch);
         }
-
-        vcsjob->disconnect(this);
+    } else {
+        KMessageBox::error(ICore::self()->uiController()->activeMainWindow(), vcsjob->errorString(), i18n("Unable to get difference."));
     }
 }
 
 void VcsPluginHelper::diffToBase()
 {
     SINGLEURL_SETUP_VARS
+    ICore::self()->documentController()->saveAllDocuments();
     KDevelop::VcsJob* job = iface->diff(url,
                                         KDevelop::VcsRevision::createSpecialRevision(KDevelop::VcsRevision::Base),
                                         KDevelop::VcsRevision::createSpecialRevision(KDevelop::VcsRevision::Working));
@@ -360,27 +341,57 @@ void VcsPluginHelper::add()
 void VcsPluginHelper::commit()
 {
     Q_ASSERT(!d->ctxUrls.isEmpty());
-    KDevelop::VcsCommitDialog* dlg = new KDevelop::VcsCommitDialog(d->plugin, d->plugin->core()->uiController()->activeMainWindow());
-//     KConfigGroup vcsGroup(KSharedConfig::openConfig(componentData()), "VcsCommon");
-//     dlg->setOldMessages(vcsGroup.readEntry("OldCommitMessages", QStringList()));
-//     dlg->setRecursive(true);
-    connect(dlg, SIGNAL(doCommit(KDevelop::VcsCommitDialog*)), this, SLOT(executeCommit(KDevelop::VcsCommitDialog*)));
-    connect(dlg, SIGNAL(cancelCommit(KDevelop::VcsCommitDialog*)), this, SLOT(cancelCommit(KDevelop::VcsCommitDialog*)));
-    dlg->setCommitCandidatesAndShow(d->ctxUrls.first());
+    ICore::self()->documentController()->saveAllDocuments();
+
+    KUrl url = d->ctxUrls.first();
+    QScopedPointer<VcsJob> statusJob(d->vcs->status(url));
+    QMap<KUrl, VcsStatusInfo::State> changes;
+    if( statusJob->exec() && statusJob->status() == VcsJob::JobSucceeded )
+    {
+        QVariant varlist = statusJob->fetchResults();
+
+        foreach( const QVariant &var, varlist.toList() )
+        {
+            VcsStatusInfo info = qVariantValue<KDevelop::VcsStatusInfo>( var );
+            
+            if(info.state()!=VcsStatusInfo::ItemUpToDate)
+                changes[info.url()] = info.state();
+        }
+    }
+    else
+        kDebug() << "Couldn't get status for urls: " << url;
+    
+    QScopedPointer<VcsJob> diffJob(d->vcs->diff(url,
+                                        KDevelop::VcsRevision::createSpecialRevision(KDevelop::VcsRevision::Base),
+                                        KDevelop::VcsRevision::createSpecialRevision(KDevelop::VcsRevision::Working)));
+
+    VcsDiff diff;
+    bool correctDiff = diffJob->exec();
+    if(correctDiff)
+        diff = diffJob->fetchResults().value<VcsDiff>();
+    
+    if(!correctDiff) {
+        KMessageBox::error(0, i18n("Could not create a patch for the current version."));
+    } else if(diff.isEmpty()) {
+        KMessageBox::information(0, i18n("Could not find any modifications to commit."));
+    } else {
+        VCSCommitDiffPatchSource* patchSource = new VCSCommitDiffPatchSource(diff, changes, d->vcs);
+        
+        bool ret = showVcsDiff(patchSource);
+        
+        Q_ASSERT(ret && "Make sure PatchReview plugin is installed correctly");
+        if(ret) {
+            connect(patchSource, SIGNAL(reviewFinished(QString,QList<KUrl>)), this, SLOT(executeCommit(QString,QList<KUrl>)));
+        } else {
+            delete patchSource;
+        }
+    }
 }
 
-void VcsPluginHelper::executeCommit(KDevelop::VcsCommitDialog* dlg)
+void VcsPluginHelper::executeCommit(const QString& message, const QList<KUrl>& urls)
 {
-    KConfigGroup vcsGroup(KSharedConfig::openConfig(d->plugin->componentData()), "VcsCommon");
-    QStringList oldMessages = vcsGroup.readEntry("OldCommitMessages", QStringList());
-    oldMessages << dlg->message();
-    vcsGroup.writeEntry("OldCommitMessages", oldMessages);
-
-    KDevelop::IBasicVersionControl* iface = dlg->versionControlPlugin()->extension<KDevelop::IBasicVersionControl>();
-    d->plugin->core()->runController()->registerJob(iface->commit(dlg->message(), dlg->determineUrlsForCheckin(),
-            dlg->recursive() ?  KDevelop::IBasicVersionControl::Recursive : KDevelop::IBasicVersionControl::NonRecursive));
-
-    dlg->deleteLater();
+    VcsJob* job=d->vcs->commit(message, urls, KDevelop::IBasicVersionControl::NonRecursive);
+    d->plugin->core()->runController()->registerJob(job);
 }
 
 void VcsPluginHelper::cancelCommit(KDevelop::VcsCommitDialog* dlg)
