@@ -46,14 +46,13 @@ public:
 private Q_SLOTS:
     void commit();
     void add();
-    void remove();
     void revert();
     void history();
     void annotation();
     void diffToHead();
     void diffToBase();
     void update();
-    void executeCommit(KDevelop::VcsCommitDialog* dlg);
+    void executeCommit(const QString& message, const QList<KUrl>& urls);
     void cancelCommit(KDevelop::VcsCommitDialog* dlg);
     void diffJobFinished(KJob* job);
 private:
